 /*! \brief C interface for the implementation of the elpa_allocate method
 *
 *  \param  none
 *  \result elpa_t handle
 */
 elpa_t elpa_allocate();
 /*! \brief C interface for the implementation of the elpa_deallocate method
 *
 *  \param  elpa_t  handle of ELPA object to be deallocated
 *  \result void
 */
 void elpa_deallocate(elpa_t handle);
 /*! \brief C interface for the implementation of the elpa_setup method
 *
 *  \param  elpa_t  handle of the ELPA object which describes the problem to
 *                  be set up
 *  \result int     error code, which can be queried with elpa_strerr
 */
 int elpa_setup(elpa_t handle);
 /*! \brief C interface for the implementation of the elpa_set_integer method
 *  This method is available to the user as C generic elpa_set method
 *
 *  \param  handle  handle of the ELPA object for which a key/value pair should be set
 *  \param  name    the name of the key
 *  \param  value   the value to be set for the key
 *  \param  error   on return the error code, which can be queried with elpa_strerr()
 *  \result void
 */
 void elpa_set_integer(elpa_t handle, const char *name, int value, int *error);
 /*! \brief C interface for the implementation of the elpa_get_integer method
 *  This method is available to the user as C generic elpa_get method
 *
 *  \param  handle  handle of the ELPA object for which a key/value pair should be queried
 *  \param  name    the name of the key
 *  \param  value   the value to be obtain for the key
 *  \param  error   on return the error code, which can be queried with elpa_strerr()
 *  \result void
 */
 void elpa_get_integer(elpa_t handle, const char *name, int *value, int *error);
 /*! \brief C interface for the implementation of the elpa_set_double method
 *  This method is available to the user as C generic elpa_set method
 *
 *  \param  handle  handle of the ELPA object for which a key/value pair should be set
 *  \param  name    the name of the key
 *  \param  value   the value to be set for the key
 *  \param  error   on return the error code, which can be queried with elpa_strerr()
 *  \result void
 */
 void elpa_set_double(elpa_t handle, const char *name, double value, int *error);
 /*! \brief C interface for the implementation of the elpa_get_double method
 *  This method is available to the user as C generic elpa_get method
 *
 *  \param  handle  handle of the ELPA object for which a key/value pair should be queried
 *  \param  name    the name of the key
 *  \param  value   the value to be obtain for the key
 *  \param  error   on return the error code, which can be queried with elpa_strerr()
 *  \result void
 */
 void elpa_get_double(elpa_t handle, const char *name, double *value, int *error);
 void elpa_eigenvectors_d(elpa_t handle, double *a, double *ev, double *q, int *error);
 void elpa_eigenvectors_f(elpa_t handle, float *a, float *ev, float *q, int *error);
 void elpa_eigenvectors_dc(elpa_t handle, double complex *a, double *ev, double complex *q, int *error);
 void elpa_eigenvectors_fc(elpa_t handle, float complex *a, float *ev, float complex *q, int *error);
 void elpa_eigenvalues_d(elpa_t handle, double *a, double *ev, int *error);
 void elpa_eigenvalues_f(elpa_t handle, float *a, float *ev, int *error);
 void elpa_eigenvalues_dc(elpa_t handle, double complex *a, double *ev, int *error);
 void elpa_eigenvalues_fc(elpa_t handle, float complex *a, float *ev, int *error);
 void elpa_hermitian_multiply_d(elpa_t handle, char uplo_a, char uplo_c, int ncb, double *a, double *b, int nrows_b, int ncols_b, double *c, int nrows_c, int ncols_c, int *error);
 void elpa_hermitian_multiply_f(elpa_t handle, char uplo_a, char uplo_c, int ncb, float *a, float *b, int nrows_b, int ncols_b, float *c, int nrows_c, int ncols_c, int *error);
 void elpa_hermitian_multiply_dc(elpa_t handle, char uplo_a, char uplo_c, int ncb, double complex *a, double complex *b, int nrows_b, int ncols_b, double complex *c, int nrows_c, int ncols_c, int *error);
 void elpa_hermitian_multiply_fc(elpa_t handle, char uplo_a, char uplo_c, int ncb, float complex *a, float complex *b, int nrows_b, int ncols_b, float complex *c, int nrows_c, int ncols_c, int *error);
 void elpa_cholesky_d(elpa_t handle, double *a, int *error);
 void elpa_cholesky_f(elpa_t handle, float *a, int *error);
 void elpa_cholesky_dc(elpa_t handle, double complex *a, int *error);
 void elpa_cholesky_fc(elpa_t handle, float complex *a, int *error);
 void elpa_invert_trm_d(elpa_t handle, double *a, int *error);
 void elpa_invert_trm_f(elpa_t handle, float *a, int *error);
 void elpa_invert_trm_dc(elpa_t handle, double complex *a, int *error);
 void elpa_invert_trm_fc(elpa_t handle, float complex *a, int *error);
 int elpa_init(int api_version);
 void elpa_uninit(void);
